@@ -15,24 +15,16 @@ _fit_transform_docstring = """fit_transform:
         Set the parameters of this estimator.
         """.rstrip()
 
-_get_feature_names_out_docstring = """
-        Get output feature names for transformation.
-
-        Parameters
-        ----------
-        input_features: str, list, default=None
-            If `None`, then the names of all the variables in the
-            transformed dataset is returned. If list with feature
-            names, the features in the list will be returned. This
-            parameter exists mostly for compatibility with the
-            Scikit-learn Pipeline.
-
-        Returns
-        -------
-        feature_names_out: list
-            The feature names.
-        """.rstrip()
-
 _inverse_transform_docstring = """inverse_transform:
         Convert the data back to the original representation.
         """.rstrip()
+
+# used in categorical encoders
+_transform_encoders_docstring = """transform:
+        Encode the categories to numbers.
+    """.rstrip()
+
+# used in creation module
+_transform_creation_docstring = """transform:
+        Create new features.
+    """.rstrip()
