@@ -4,19 +4,26 @@ import pandas as pd
 from sklearn.base import clone
 from sklearn.model_selection import cross_validate
 
-from feature_engine._prediction.target_mean_classifier import TargetMeanClassifier
-from feature_engine._prediction.target_mean_regressor import TargetMeanRegressor
-from feature_engine.dataframe_checks import check_X_y
-from feature_engine._docstrings.methods import _fit_transform_docstring
 from feature_engine._docstrings.fit_attributes import (
     _feature_names_in_docstring,
     _n_features_in_docstring,
 )
+from feature_engine._docstrings.methods import _fit_transform_docstring
 from feature_engine._docstrings.substitute import Substitution
+from feature_engine._prediction.target_mean_classifier import TargetMeanClassifier
+from feature_engine._prediction.target_mean_regressor import TargetMeanRegressor
+from feature_engine._variable_handling.init_parameter_checks import (
+    _check_init_parameter_variables,
+)
+from feature_engine._variable_handling.variable_type_selection import (
+    _find_all_variables,
+)
+from feature_engine.dataframe_checks import check_X_y
 from feature_engine.selection._docstring import (
     _cv_docstring,
     _features_to_drop_docstring,
     _fit_docstring,
+    _get_support_docstring,
     _scoring_docstring,
     _threshold_docstring,
     _transform_docstring,
@@ -28,10 +35,6 @@ from feature_engine.selection._selection_constants import (
 )
 from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.tags import _return_tags
-from feature_engine.variable_manipulation import (
-    _check_input_parameter_variables,
-    _find_all_variables,
-)
 
 Variables = Union[None, int, str, List[Union[str, int]]]
 
@@ -48,6 +51,7 @@ Variables = Union[None, int, str, List[Union[str, int]]]
     fit=_fit_docstring,
     transform=_transform_docstring,
     fit_transform=_fit_transform_docstring,
+    get_support=_get_support_docstring,
 )
 class SelectByTargetMeanPerformance(BaseSelector):
     """
@@ -142,6 +146,8 @@ class SelectByTargetMeanPerformance(BaseSelector):
 
     {fit_transform}
 
+    {get_support}
+
     {transform}
 
     Notes
@@ -203,7 +209,7 @@ class SelectByTargetMeanPerformance(BaseSelector):
             )
 
         super().__init__(confirm_variables)
-        self.variables = _check_input_parameter_variables(variables)
+        self.variables = _check_init_parameter_variables(variables)
         self.bins = bins
         self.strategy = strategy
         self.scoring = scoring
