@@ -6,21 +6,23 @@ from typing import List, Optional, Union
 import numpy as np
 import pandas as pd
 
-from feature_engine.base_transformers import BaseNumericalTransformer
+from feature_engine._base_transformers.base_numerical import BaseNumericalTransformer
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+    _variables_attribute_docstring,
+)
+from feature_engine._docstrings.init_parameters import _variables_numerical_docstring
 from feature_engine._docstrings.methods import (
     _fit_not_learn_docstring,
     _fit_transform_docstring,
     _inverse_transform_docstring,
 )
-from feature_engine._docstrings.fit_attributes import (
-    _variables_attribute_docstring,
-    _feature_names_in_docstring,
-    _n_features_in_docstring,
-)
-from feature_engine._docstrings.class_inputs import _variables_numerical_docstring
 from feature_engine._docstrings.substitute import Substitution
+from feature_engine._variable_handling.init_parameter_checks import (
+    _check_init_parameter_variables,
+)
 from feature_engine.tags import _return_tags
-from feature_engine.variable_manipulation import _check_input_parameter_variables
 
 
 @Substitution(
@@ -75,7 +77,7 @@ class ReciprocalTransformer(BaseNumericalTransformer):
         self, variables: Union[None, int, str, List[Union[str, int]]] = None
     ) -> None:
 
-        self.variables = _check_input_parameter_variables(variables)
+        self.variables = _check_init_parameter_variables(variables)
 
     def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
         """
@@ -92,7 +94,7 @@ class ReciprocalTransformer(BaseNumericalTransformer):
         """
 
         # check input dataframe
-        X = super()._fit_from_varlist(X)
+        X = super().fit(X)
 
         # check if the variables contain the value 0
         if (X[self.variables_] == 0).any().any():
